@@ -1,4 +1,4 @@
-// $Id: vserver-internal.h,v 1.13 2004/02/02 18:59:11 ensc Exp $    --*- c++ -*--
+// $Id: vserver-internal.h,v 1.14 2004/02/04 23:38:39 ensc Exp $    --*- c++ -*--
 
 // Copyright (C) 2003 Enrico Scholz <enrico.scholz@informatik.tu-chemnitz.de>
 //  
@@ -157,7 +157,7 @@
 #define EXT2_IOC_SETCONTEXT		_IOW('x', 2, long)
 
 #ifndef HAVE_VSERVER
-#if defined(__pic__) && defined(__i386)
+#ifdef ENSC_SYSCALL_TRADITIONAL
 inline static UNUSED ALWAYSINLINE
 int vserver(uint32_t cmd, uint32_t id, void *data)
 {
